@@ -16,18 +16,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id$
  */
 
 #include "config.h"
 
-#include <epiphany/ephy-statusbar.h>
-#include <epiphany/ephy-window.h>
-#include <epiphany/ephy-adblock.h>
-#include <epiphany/ephy-adblock-manager.h>
-#include <epiphany/ephy-embed-container.h>
-#include <epiphany/ephy-embed-shell.h>
-#include <epiphany/ephy-extension.h>
+#include <epiphany/epiphany.h>
 
 #include "ephy-adblock-extension.h"
 #include "ephy-debug.h"
@@ -37,14 +30,7 @@
 #include "ad-uri-tester.h"
 #include "adblock-ui.h"
 
-#include <gtk/gtkaction.h>
-#include <gtk/gtkactiongroup.h>
-#include <gtk/gtkeventbox.h>
-#include <gtk/gtkiconfactory.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtknotebook.h>
-#include <gtk/gtkuimanager.h>
-#include <gtk/gtkstock.h>
+#include <gtk/gtk.h>
 
 #include <gmodule.h>
 
@@ -254,6 +240,7 @@ ephy_adblock_statusbar_icon_clicked_cb (GtkWidget *widget,
 	{
 		EphyAdblockExtension *ext;
 		AdBlocker *blocker;
+		WebKitWebView *view;
 		EphyEmbed *embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (window));
 
 		ext = EPHY_ADBLOCK_EXTENSION (g_object_get_data (G_OBJECT (window),
@@ -264,7 +251,8 @@ ephy_adblock_statusbar_icon_clicked_cb (GtkWidget *widget,
 
 		ad_blocker_set_noblock (blocker);
 
-		ephy_embed_reload (embed, FALSE);
+		view = EPHY_GET_WEBKIT_WEB_VIEW_FROM_EMBED (embed);
+		webkit_web_view_reload (view);
 
 		return TRUE;
 	}
