@@ -26,7 +26,7 @@
 #include "ephy-push-scroller.h"
 #include "ephy-debug.h"
 
-#include <epiphany/ephy-extension.h>
+#include <epiphany/epiphany.h>
 
 #include <gmodule.h>
 
