@@ -16,20 +16,18 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: sidebar-commands.c,v 1.6 2006/09/13 19:01:36 chpe Exp $
+ *  $Id$
  */
 
 #include "config.h"
 
 #include "sidebar-commands.h"
 
-#include <epiphany/ephy-embed.h>
-#include <epiphany/ephy-embed-factory.h>
-#include <epiphany/ephy-embed-persist.h>
+#include <epiphany/epiphany.h>
 
 #include "ephy-prefs.h"
 
-#include <gtk/gtkwindow.h>
+#include <gtk/gtk.h>
 
 /* NOTE: we include gi18n.h instead of gi18n-lib.h since all string here
  * are the same as in epiphany. If that ever changes, fix this include!
@@ -50,8 +48,8 @@ sidebar_cmd_file_save_as (GtkAction *action,
 
 	window = ephy_sidebar_embed_get_window (sidebar);
 
-	persist = EPHY_EMBED_PERSIST
-		(ephy_embed_factory_new_object (EPHY_TYPE_EMBED_PERSIST));
+        persist = EPHY_EMBED_PERSIST
+          (g_object_new (EPHY_TYPE_EMBED_PERSIST, NULL));
 
 	ephy_embed_persist_set_embed (persist, embed);
 	ephy_embed_persist_set_fc_title (persist, _("Save As"));
@@ -91,8 +89,8 @@ save_property_url (GtkAction *action,
 	value = ephy_embed_event_get_property (event, property);
 	location = g_value_get_string (value);
 
-	persist = EPHY_EMBED_PERSIST
-		(ephy_embed_factory_new_object (EPHY_TYPE_EMBED_PERSIST));
+        persist = EPHY_EMBED_PERSIST
+          (g_object_new (EPHY_TYPE_EMBED_PERSIST, NULL));
 
 	ephy_embed_persist_set_embed (persist, embed);
 	ephy_embed_persist_set_fc_title (persist, title);
@@ -126,9 +124,9 @@ sidebar_cmd_open_frame (GtkAction *action,
 	embed = ephy_sidebar_embed_get_embed (sidebar);
 	g_return_if_fail (embed != NULL);
 
-	location = ephy_embed_get_location (embed, FALSE);
+	location = ephy_web_view_get_location (EPHY_GET_EPHY_WEB_VIEW_FROM_EMBED (embed), FALSE);
 
-	ephy_embed_load_url (embed, location);
+	ephy_web_view_load_url (EPHY_GET_EPHY_WEB_VIEW_FROM_EMBED (embed), location);
 
 	g_free (location);
 }
